# 通用基础库 

版本: v0.1.1

可对目录下的文件进行以下批量处理：

* 清除空格 空行 按句子分行；
* 删除空文件，找到后改名（改为"原文件名.del") 或者直接删除
* 删除重复的文件:   根据文件的MD5判断文件是否相同，找到后改名（原文件.same)或者直接删除
* 批量重命名:    可按序号进行重命名，默认从1开始，文件名会自动在前面补0，例如"0001.txt"
* 可统计文本文件的行数  [2019/1/18 添加]
* 对数据进行检查；
* 对数据重复数据检查并删除；
* 对数据进行随机抽样；
* 处理参数可以自定义顺序，
